# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/merkle.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/merkle.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\025sawtooth.sdk.protobufP\001Z\nmerkle_pb2'),
  serialized_pb=_b('\n\x1d\x64gt_sdk/protobuf/merkle.proto\"\x95\x01\n\x0e\x43hangeLogEntry\x12\x0e\n\x06parent\x18\x01 \x01(\x0c\x12\x11\n\tadditions\x18\x02 \x03(\x0c\x12-\n\nsuccessors\x18\x03 \x03(\x0b\x32\x19.ChangeLogEntry.Successor\x1a\x31\n\tSuccessor\x12\x11\n\tsuccessor\x18\x01 \x01(\x0c\x12\x11\n\tdeletions\x18\x02 \x03(\x0c\x42%\n\x15sawtooth.sdk.protobufP\x01Z\nmerkle_pb2b\x06proto3')
)




_CHANGELOGENTRY_SUCCESSOR = _descriptor.Descriptor(
  name='Successor',
  full_name='ChangeLogEntry.Successor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='successor', full_name='ChangeLogEntry.Successor.successor', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deletions', full_name='ChangeLogEntry.Successor.deletions', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=183,
)

_CHANGELOGENTRY = _descriptor.Descriptor(
  name='ChangeLogEntry',
  full_name='ChangeLogEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='ChangeLogEntry.parent', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='additions', full_name='ChangeLogEntry.additions', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='successors', full_name='ChangeLogEntry.successors', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CHANGELOGENTRY_SUCCESSOR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=183,
)

_CHANGELOGENTRY_SUCCESSOR.containing_type = _CHANGELOGENTRY
_CHANGELOGENTRY.fields_by_name['successors'].message_type = _CHANGELOGENTRY_SUCCESSOR
DESCRIPTOR.message_types_by_name['ChangeLogEntry'] = _CHANGELOGENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ChangeLogEntry = _reflection.GeneratedProtocolMessageType('ChangeLogEntry', (_message.Message,), dict(

  Successor = _reflection.GeneratedProtocolMessageType('Successor', (_message.Message,), dict(
    DESCRIPTOR = _CHANGELOGENTRY_SUCCESSOR,
    __module__ = 'dgt_sdk.protobuf.merkle_pb2'
    # @@protoc_insertion_point(class_scope:ChangeLogEntry.Successor)
    ))
  ,
  DESCRIPTOR = _CHANGELOGENTRY,
  __module__ = 'dgt_sdk.protobuf.merkle_pb2'
  # @@protoc_insertion_point(class_scope:ChangeLogEntry)
  ))
_sym_db.RegisterMessage(ChangeLogEntry)
_sym_db.RegisterMessage(ChangeLogEntry.Successor)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
